Distributions
==============

This module provides probability distribution implementations for concept-based models.

.. currentmodule:: torch_concepts.distributions

Summary
-------

**Distribution Classes**

.. autosummary::
   :toctree: generated
   :nosignatures:

   Delta


Class Documentation
-------------------

.. autoclass:: Delta
   :members:
   :undoc-members:
   :show-inheritance:
